searchData={"items":[{"type":"module","title":"URL","doc":"Functions for parsing URLs.\n\nThis module provides functions for parsing URLs. It is modelled on\nElixir's `URI` module but will also parse scheme-specific URIs such\nas [geo](https://tools.ietf.org/rfc/rfc5870), [data](https://tools.ietf.org/html/rfc2397)\n[tel](https://tools.ietf.org/html/rfc3966), [mailto](https://tools.ietf.org/html/rfc2047),\nand [uuid](https://tools.ietf.org/html/draft-kindel-uuid-uri-00).","ref":"URL.html"},{"type":"function","title":"URL.new/1","doc":"Parses a string url and returns a `t:URL.t/0` struct that\nhas the same shape as Elixir's `t:URI.t/0` with the\naddition of the `parsed_path` key.\n\n#","ref":"URL.html#new/1"},{"type":"function","title":"Arguments - URL.new/1","doc":"* `url` is a binary representation of a URL.\n\n#","ref":"URL.html#new/1-arguments"},{"type":"function","title":"Returns - URL.new/1","doc":"* `{:ok, URL.t()}` or\n\n* `{:error, {exception, reason}}`.\n\n#","ref":"URL.html#new/1-returns"},{"type":"function","title":"Example - URL.new/1","doc":"iex> URL.new(\"geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0\")\n    {:ok,\n      %URL{\n        authority: nil,\n        fragment: nil,\n        host: nil,\n        parsed_path: %URL.Geo{\n          alt: 3.4,\n          lat: 48.198634,\n          lng: -16.371648,\n          params: %{\"crs\" => \"wgs84\", \"u\" => 40.0}\n        },\n        path: \"48.198634,-16.371648,3.4;crs=wgs84;u=40.0\",\n        port: nil,\n        query: nil,\n        scheme: \"geo\",\n        userinfo: nil\n      }\n    }\n\n    iex> URL.new(\"geo:48.198634,--16.371648,3.4;crs=wgs84;u=40.0\")\n    {:error,\n     {URL.Parser.ParseError,\n      \"expected an string of digits while processing lat inside alt inside geo data. Detected on line 1 at \\\"-16.371648,3.4;crs=w\\\"   ...\"}}\n\n    iex> URL.new \"/invalid_greater_than_in_path/>\"\n    {:error,\n     {URI.Error,\n      \"cannot parse due to reason invalid_uri: \\\">\\\"\"}}","ref":"URL.html#new/1-example"},{"type":"function","title":"URL.new!/1","doc":"Parses a string url and returns a `t:URL.t/0` struct that\nhas the same shape as Elixir's `t:URI.t/0` with the\naddition of the `parsed_path` key, or raises an exception.\n\n#","ref":"URL.html#new!/1"},{"type":"function","title":"Arguments - URL.new!/1","doc":"* `url` is a binary representation of a URL.\n\n#","ref":"URL.html#new!/1-arguments"},{"type":"function","title":"Returns - URL.new!/1","doc":"* `t:URL.t/0` or\n\n* raises an exception.\n\n#","ref":"URL.html#new!/1-returns"},{"type":"function","title":"Example - URL.new!/1","doc":"iex> URL.new!(\"geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0\")\n    %URL{\n      authority: nil,\n      fragment: nil,\n      host: nil,\n      parsed_path: %URL.Geo{\n        alt: 3.4,\n        lat: 48.198634,\n        lng: -16.371648,\n        params: %{\"crs\" => \"wgs84\", \"u\" => 40.0}\n      },\n      path: \"48.198634,-16.371648,3.4;crs=wgs84;u=40.0\",\n      port: nil,\n      query: nil,\n      scheme: \"geo\",\n      userinfo: nil\n    }","ref":"URL.html#new!/1-example"},{"type":"function","title":"URL.parse_query_string/1","doc":"Parse and percent decode a URL query string.\n\n#","ref":"URL.html#parse_query_string/1"},{"type":"function","title":"Returns - URL.parse_query_string/1","doc":"* Either a map of query params or\n\n* an `{:error, {URL.Parser.ParseError, reason}}` tuple.\n\n#","ref":"URL.html#parse_query_string/1-returns"},{"type":"function","title":"Examples - URL.parse_query_string/1","doc":"iex> URL.parse_query_string(\"url=http%3a%2f%2ffonzi.com%2f&name=Fonzi&mood=happy&coat=leather\")\n    %{\n      \"coat\" => \"leather\",\n      \"mood\" => \"happy\",\n      \"name\" => \"Fonzi\",\n      \"url\" => \"http://fonzi.com/\"\n    }\n\n    iex> mailto = \"mailto:user@%E7%B4%8D%E8%B1%86.example.org?subject=Test&body=NATTO\"\n    iex> URL.new!(mailto) |> URL.parse_query_string()\n    %{\"body\" => \"NATTO\", \"subject\" => \"Test\"}","ref":"URL.html#parse_query_string/1-examples"},{"type":"function","title":"URL.to_string/1","doc":"Returns the string representation of the given URL struct (t:t/0).\n\nThis function delegates to `URI.to_string/1`.\n\n#","ref":"URL.html#to_string/1"},{"type":"function","title":"Arguments - URL.to_string/1","doc":"* `url` is any `t:URL.t/0`.\n\n#","ref":"URL.html#to_string/1-arguments"},{"type":"function","title":"Returns - URL.to_string/1","doc":"* a string representation of the URL.\n\n#","ref":"URL.html#to_string/1-returns"},{"type":"function","title":"Examples - URL.to_string/1","doc":"iex> {:ok, geo_url} = URL.new(\"geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0\")\n    iex> URL.to_string(geo_url)\n    \"geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0\"","ref":"URL.html#to_string/1-examples"},{"type":"type","title":"URL.t/0","doc":"","ref":"URL.html#t:t/0"},{"type":"type","title":"URL.uri_type/0","doc":"","ref":"URL.html#t:uri_type/0"},{"type":"module","title":"URL.Data","doc":"Parses a `data` URL","ref":"URL.Data.html"},{"type":"function","title":"URL.Data.parse/1","doc":"Parse a URI with the `:scheme` of \"data\"","ref":"URL.Data.html#parse/1"},{"type":"function","title":"Example - URL.Data.parse/1","doc":"iex> data = URI.parse \"data:text/plain;base64,SGVsbG8gV29ybGQh\"\n    iex> URL.Data.parse(data)\n    {:ok,\n     %URL.Data{\n       mediatype: \"text/plain\",\n       params: %{\"encoding\" => \"base64\"},\n       data: \"Hello World!\"\n     }}","ref":"URL.Data.html#parse/1-example"},{"type":"type","title":"URL.Data.t/0","doc":"","ref":"URL.Data.html#t:t/0"},{"type":"module","title":"URL.Geo","doc":"Parses a `geo` URL","ref":"URL.Geo.html"},{"type":"function","title":"URL.Geo.parse/1","doc":"Parse a URI with the `:scheme` of \"geo\"","ref":"URL.Geo.html#parse/1"},{"type":"function","title":"Example - URL.Geo.parse/1","doc":"iex> geo = URI.parse(\"geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0\")\n    iex> URL.Geo.parse(geo)\n    {:ok,\n     %URL.Geo{\n       lat: 48.198634,\n       lng: -16.371648,\n       alt: 3.4,\n       params: %{\"crs\" => \"wgs84\", \"u\" => 40.0}\n     }}","ref":"URL.Geo.html#parse/1-example"},{"type":"type","title":"URL.Geo.t/0","doc":"","ref":"URL.Geo.html#t:t/0"},{"type":"module","title":"URL.Mailto","doc":"Parses a `mailto` URL","ref":"URL.Mailto.html"},{"type":"function","title":"URL.Mailto.parse/1","doc":"Parse a URI with the `:scheme` of \"tel\"","ref":"URL.Mailto.html#parse/1"},{"type":"function","title":"Example - URL.Mailto.parse/1","doc":"iex> mailto = URI.parse(\"mailto:user@%E7%B4%8D%E8%B1%86.example.org?subject=Test&body=NATTO\")\n    iex> URL.Mailto.parse(mailto)\n    {:ok,\n     %URL.Mailto{\n       to: [\"user@納豆.example.org\"],\n       params: %{\"body\" => \"NATTO\", \"subject\" => \"Test\"}\n     }}","ref":"URL.Mailto.html#parse/1-example"},{"type":"type","title":"URL.Mailto.t/0","doc":"","ref":"URL.Mailto.html#t:t/0"},{"type":"module","title":"URL.Tel","doc":"Parses a `tel` URL","ref":"URL.Tel.html"},{"type":"function","title":"URL.Tel.parse/1","doc":"Parse a URI with the `:scheme` of \"tel\"","ref":"URL.Tel.html#parse/1"},{"type":"function","title":"Examples - URL.Tel.parse/1","doc":"iex> tel = URI.parse \"tel:+61-0407-555-987\"\n    iex> URL.Tel.parse(tel)\n    {:ok, %URL.Tel{tel: \"+61 407 555 987\", params: %{}}}\n\n    iex> tel = URI.parse \"tel:0407-555-987;phone-context=+61\"\n    iex> URL.Tel.parse(tel)\n    {:ok, %URL.Tel{tel: \"+61 407 555 987\", params: %{\"phone-context\" => \"+61\"}}}","ref":"URL.Tel.html#parse/1-examples"},{"type":"type","title":"URL.Tel.t/0","doc":"","ref":"URL.Tel.html#t:t/0"},{"type":"module","title":"URL.UUID","doc":"Parses a `geo` URL","ref":"URL.UUID.html"},{"type":"function","title":"URL.UUID.parse/1","doc":"Parse a URI with the `:scheme` of \"uuid\"","ref":"URL.UUID.html#parse/1"},{"type":"function","title":"Example - URL.UUID.parse/1","doc":"iex> uuid = URI.parse(\"uuid:f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b\")\n    iex> URL.UUID.parse(uuid)\n    {:ok,\n     %URL.UUID{uuid: \"f81d4fae-7dec-11d0-a765-00a0c91e6bf6\", params: %{\"a\" => \"b\"}}}\n\n    iex> uuid = URI.parse(\"urn:uuid:f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b\")\n    iex> URL.UUID.parse(uuid)\n    {:ok, %URL.UUID{params: %{\"a\" => \"b\"}, uuid: \"f81d4fae-7dec-11d0-a765-00a0c91e6bf6\"}}","ref":"URL.UUID.html#parse/1-example"},{"type":"type","title":"URL.UUID.t/0","doc":"","ref":"URL.UUID.html#t:t/0"},{"type":"exception","title":"URL.Parser.ParseError","doc":"Exception raised when a URL cannot be parsed","ref":"URL.Parser.ParseError.html"},{"type":"extras","title":"Getting Started","doc":"# Getting Started\n\n[![Hex pm](http://img.shields.io/hexpm/v/ex_url.svg?style=flat)](https://hex.pm/packages/ex_url)\n[![License](https://img.shields.io/badge/license-Apache%202-blue.svg)](https://github.com/kipcole9/url/blob/master/LICENSE.md)","ref":"readme.html"},{"type":"extras","title":"Overview - Getting Started","doc":"`ex_url` is a library modelled on the Elixir URI module. It parses and formats URL's with the additional function that is parses the scheme-specific payload of known URI schemes.  At present it can parse:\n\n* [geo](https://tools.ietf.org/rfc/rfc5870)\n* [data](https://tools.ietf.org/html/rfc2397)\n* [mailto](https://tools.ietf.org/html/rfc6068)\n* [uuid](https://tools.ietf.org/html/draft-kindel-uuid-uri-00)\n* and [tel](https://tools.ietf.org/html/rfc3966)\n\nThe basic API is `URL.new/1`.  The function `URL.to_string/1` is delegated to the URI module.\n\nOf course these are really URI's, not URL's but its a reasonable choice of name\ngiven that [WHATWG](https://en.wikipedia.org/wiki/WHATWG) prefers URL over URI:\n\n> Standardize on the term URL. URI and IRI [Internationalized Resource Identifier]\n> are just confusing. In practice a single algorithm is used for both so keeping\n> them distinct is not helping anyone. URL also easily wins the search result\n> popularity contest","ref":"readme.html#overview"},{"type":"extras","title":"Examples - Getting Started","doc":"#","ref":"readme.html#examples"},{"type":"extras","title":"Parse a `geo` URL: - Getting Started","doc":"```elixir\niex> URL.new(\"geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0\")\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.Geo{\n      alt: 3.4,\n      lat: 48.198634,\n      lng: -16.371648,\n      params: %{\"crs\" => \"wgs84\", \"u\" => 40.0}\n    },\n    path: \"48.198634,-16.371648,3.4;crs=wgs84;u=40.0\",\n    port: nil,\n    query: nil,\n    scheme: \"geo\",\n    userinfo: nil\n  }\n}\n```\n#","ref":"readme.html#parse-a-geo-url"},{"type":"extras","title":"Parse a `tel` URL: - Getting Started","doc":"```elixir\niex> URL.new(\"tel:+61-0407-555-987\")\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.Tel{params: %{}, tel: \"+61 407 555 987\"},\n    path: \"+61-0407-555-987\",\n    port: nil,\n    query: nil,\n    scheme: \"tel\",\n    userinfo: nil\n  }\n}\n# When the parameter \"phone-context\" is also a valid number then it is prepended before formatting\niex> tel = URL.new \"tel:0407-555-987;phone-context=+61\"\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.Tel{\n      params: %{\"phone-context\" => \"+61\"},\n      tel: \"+61 407 555 987\"\n    },\n    path: \"0407-555-987;phone-context=+61\",\n    port: nil,\n    query: nil,\n    scheme: \"tel\",\n    userinfo: nil\n  }\n}\n```\n#","ref":"readme.html#parse-a-tel-url"},{"type":"extras","title":"Parse a `data` URL: - Getting Started","doc":"This first example shows the treatment of data that is `base64` encoded.  It is decoded by `URL.Data.parse/1`.\n```elixir\niex> URL.new(\"data:;base64,SGVsbG8gV29ybGQh\")\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.Data{\n      data: \"Hello World!\",\n      mediatype: \"text/plain\",\n      params: %{\"encoding\" => \"base64\"}\n    },\n    path: \";base64,SGVsbG8gV29ybGQh\",\n    port: nil,\n    query: nil,\n    scheme: \"data\",\n    userinfo: nil\n  }\n}\n```\nThis second example shows the treatment of data that is not marked as `base64` encoded.  In this case it is considered to be `percent-encoded`.  It is also decoded during parsing.\n```elixir\niex> URL.new(\"data:,Hello%20World%21\")\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.Data{\n      data: \"Hello World!\",\n      mediatype: \"text/plain\",\n      params: %{}\n    },\n    path: \",Hello%20World%21\",\n    port: nil,\n    query: nil,\n    scheme: \"data\",\n    userinfo: nil\n  }\n}\n```\n#","ref":"readme.html#parse-a-data-url"},{"type":"extras","title":"Parse a `mailto` URL - Getting Started","doc":"A `mailto` URL will be parsed and percent encoding will be decoded.  Note that [RFC2047 encoded-words](https://tools.ietf.org/html/rfc2047) is not currently supported.\n```elixir\niex> URL.new(\"mailto:infobot@example.com?subject=current-issue\")\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.Mailto{\n      params: %{\"subject\" => \"current-issue\"},\n      to: [\"infobot@example.com\"]\n    },\n    path: \"infobot@example.com\",\n    port: nil,\n    query: \"subject=current-issue\",\n    scheme: \"mailto\",\n    userinfo: nil\n  }\n}\n```\n#","ref":"readme.html#parse-a-mailto-url"},{"type":"extras","title":"Parse a `uuid` URL - Getting Started","doc":"```elixir\niex> URL.new(\"uuid:f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b\")\n{:ok,\n  %URL{\n    authority: nil,\n    fragment: nil,\n    host: nil,\n    parsed_path: %URL.UUID{\n      params: %{\"a\" => \"b\"},\n      uuid: \"f81d4fae-7dec-11d0-a765-00a0c91e6bf6\"\n    },\n    path: \"f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b\",\n    port: nil,\n    query: nil,\n    scheme: \"uuid\",\n    userinfo: nil\n  }\n}\n```","ref":"readme.html#parse-a-uuid-url"},{"type":"extras","title":"Configuration - Getting Started","doc":"Configure `:ex_url` in `mix.exs`:\n```elixir\n  defp deps do\n    [\n      {:ex_url, \"~> 1.5\"},\n      ...\n    ]\n  end\n```\n\nIf configured in `mix.exs`, URL will use the following libraries:\n\n* [ex_phone_number](https://hex.pm/packages/ex_phone_number) will be used to parse and format telephone numbers defined in the `tel` URI scheme\n\n* [ex_cldr](https://hex.pm/packages/ex_cldr) and [gettext](https://hex.pm/packages/gettext) will be used to determine the current locale and therefore the current territory (country) for parsing and formatting telephone numbers that don't have a country code supplied.\n\nOptional configuration in `mix.exs`:\n```elixir\n  defp deps do\n    [\n      # Required\n      {:ex_url, \"~> 1.5\"},\n\n      # Optional\n      {:ex_phone_number, \"~> 0.1\"},\n      {:ex_cldr, \"~> 2.18\"},\n      {:gettext, \"~> 0.13\"}\n      ...\n    ]\n  end\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Copyright and License - Getting Started","doc":"Copyright 2018-2023 Kip Cole\n\nSee LICENCE.md for the licence terms.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Apache License","doc":"# Apache License\n\nVersion 2.0, January 2004\n\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html"},{"type":"extras","title":"1. Definitions. - Apache License","doc":"\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.","ref":"license.html#1-definitions"},{"type":"extras","title":"2. Grant of Copyright License. - Apache License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license"},{"type":"extras","title":"3. Grant of Patent License. - Apache License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including a\ncross-claim or counterclaim in a lawsuit) alleging that the Work or a\nContribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license"},{"type":"extras","title":"4. Redistribution. - Apache License","doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n1. You must give any other recipients of the Work or Derivative Works a copy of\n   this License; and\n\n2. You must cause any modified files to carry prominent notices stating that\n   You changed the files; and\n\n3. You must retain, in the Source form of any Derivative Works that You\n   distribute, all copyright, patent, trademark, and attribution notices from\n   the Source form of the Work, excluding those notices that do not pertain to\n   any part of the Derivative Works; and\n\n4. If the Work includes a \"NOTICE\" text file as part of its distribution, then\n   any Derivative Works that You distribute must include a readable copy of the\n   attribution notices contained within such NOTICE file, excluding those\n   notices that do not pertain to any part of the Derivative Works, in at least\n   one of the following places: within a NOTICE text file distributed as part\n   of the Derivative Works; within the Source form or documentation, if\n   provided along with the Derivative Works; or, within a display generated by\n   the Derivative Works, if and wherever such third-party notices normally\n   appear. The contents of the NOTICE file are for informational purposes only\n   and do not modify the License. You may add Your own attribution notices\n   within Derivative Works that You distribute, alongside or as an addendum to\n   the NOTICE text from the Work, provided that such additional attribution\n   notices cannot be construed as modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.","ref":"license.html#4-redistribution"},{"type":"extras","title":"5. Submission of Contributions. - Apache License","doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.","ref":"license.html#5-submission-of-contributions"},{"type":"extras","title":"6. Trademarks. - Apache License","doc":"This License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.","ref":"license.html#6-trademarks"},{"type":"extras","title":"7. Disclaimer of Warranty. - Apache License","doc":"Unless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE, NON-\nINFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.","ref":"license.html#7-disclaimer-of-warranty"},{"type":"extras","title":"8. Limitation of Liability. - Apache License","doc":"In no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability"},{"type":"extras","title":"9. Accepting Warranty or Additional Liability. - Apache License","doc":"While redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","ref":"license.html#9-accepting-warranty-or-additional-liability"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"URL v2.0.0 - Changelog","doc":"This is the changelog for URL version 2.0.0 released on August 4th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n**URL version 2.0.0 is supported on Elixir 1.13 and later only.**\n\n#","ref":"changelog.html#url-v2-0-0"},{"type":"extras","title":"Breaking Change - Changelog","doc":"* `URL.new/1` now always returns a tuple of the form `{:ok, t:URL.t/0}` or `{:error, {module(), String.t()}}`. The previous versions embedded error tuples in the return structure making is too complex to determine if there was a parsing error on the path data.  This approach also makes it more straight forward to implement tests that return errors.\n\n#","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Hard deprecates `URL.parse/1`\n\n#","ref":"changelog.html#deprecations"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove warnings for unused variables when neither `ex_phone_number` or `ex_cldr` are configured (these are both optional dependencies). Thanks to @shahryarjb for the report. Closes #5.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"URL v1.5.0 - Changelog","doc":"This is the changelog for URL version 1.5.0 released on July 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n`URL` version 1.5.0 is supported on Elixir 1.11 and later only.\n\n#","ref":"changelog.html#url-v1-5-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Change to `import Config`, not `import Mix.Config`\n\n* Make `Jason` dependency optional.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"URL v1.4.0 - Changelog","doc":"This is the changelog for URL version 1.4.0 released on October 30th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v1-4-0"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Soft deprecated `URL.parse/1` in line with Elixir 1.13's deprecation of `URI.parse/1`\n\n#","ref":"changelog.html#deprecations"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `URL.new/1` and `URL.new!/1` in line with the preferred API in Elixir 1.13","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v1.3.1 - Changelog","doc":"This is the changelog for URL version 1.3.1 released on May 12th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v1-3-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates `nimble_parsec` dependency to `~> 1.0`. Thanks to @ghry5\n\n* Make `ex_doc` available only in `:dev` and `:release`","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v1.3.0 - Changelog","doc":"This is the changelog for URL version 1.3.0 released on November 1st.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v1-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct some types to use `map()`\n\n* Fix error resulting from inconsistent use of territories as atoms and strings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"URL v1.2.0 - Changelog","doc":"This is the changelog for URL version 1.2.0 released on January 23rd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v1-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Executes `String.trim/1` on parsed elements of URI's so that \"https://     google.fr\" will return \"google.fr\" as the host, not \"    google.fr\".","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v1.1.0 - Changelog","doc":"This is the changelog for URL version 1.1.0 released on April 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v1-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to `NimbleParsec` version 0.5","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v1.0.0 - Changelog","doc":"This is the changelog for URL version 1.0.0 released on November 25th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Supports [ex_cldr version 2.0.0](https://hex.pm/packages/ex_cldr).  This is an optional dependency.\n\n* Add `URL.parse_query_string/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v0.4.0 - Changelog","doc":"This is the changelog for URL version 0.4.0 released on October 18th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v0-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds support for the `uuid` URL type.  See `URL.UUID`","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v0.3.0 - Changelog","doc":"This is the changelog for URL version 0.3.0 released on October 16th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v0-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds support for the `mailto` URL type.  See `URL.Mailto`\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Now correctly uses the `phone-context` parameter when formatting a telelphone number in a `tel` URL.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"URL v0.2.0 - Changelog","doc":"This is the changelog for URL version 0.2.0 released on October 13th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v0-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add specs to public functions\n\n* Make several functions private including the `defparsec` definitions","ref":"changelog.html#enhancements"},{"type":"extras","title":"URL v0.1.0 - Changelog","doc":"This is the changelog for URL version 0.1.0 released on October 13th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/url/tags)\n\n#","ref":"changelog.html#url-v0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release of URL","ref":"changelog.html#enhancements"}],"content_type":"text/markdown"}